@@ -23,13 +23,11 @@ project_path = dirname(dirname(abspath(__file__)))
 projec_full_path = project_path + r'\common'
 sys.path.append(projec_full_path)
 
-
 import requests
 import base64
 import random
 from urllib import parse
 
-
 from KCrypto.Cipher import PKCS1_v1_5
 from KCrypto.Hash import SHA
 from KCrypto.PublicKey import RSA
@@ -101,13 +99,13 @@ class KaisaCrypto(object):
     def encrypt_rsa_username(self, username, crypto_rsa_url):
 
         account_rsa = requests.get(url=crypto_rsa_url, params={'username': username})
-        if (account_rsa.status_code//100!=2):
+        if (account_rsa.status_code // 100!=2):
             return None
         pubkey = json.loads(account_rsa.text)["body"]
         pubkey_lines = []
-        for i in range(len(pubkey )//64 +1):
-            str_ = pubkey[(i) *64:( i+1 ) *64]
-            if len(str_ ) >0:
+        for i in range(len(pubkey)//64 + 1):
+            str_ = pubkey[i * 64:(i+1) * 64]
+            if len(str_) > 0:
                 pubkey_lines.append(str_)
         pubkey_lines = ["-----BEGIN RSA PUBLIC KEY-----"] + pubkey_lines + ["-----END RSA PUBLIC KEY-----"]
         pubkey = "\n".join(pubkey_lines)
@@ -117,7 +115,6 @@ class KaisaCrypto(object):
         username_rsa = cipher_text.decode()
         return username_rsa
 
-
     def encrypt_rsa_secretQ(self, crypto_rsa_url):
 
         private_text = self._produce_encrypt_privatekey()
